class EmailService:
    def __init__(self, server: str, port: int, max_size_bytes: int):
        self.server = server
        self.port = port
        self.max_size_bytes = max_size_bytes


class Gmail(EmailService):
    def __init__(self):
        super().__init__("smtp.gmail.com", 587, 25 * 1024 * 1024)


class Orange(EmailService):
    def __init__(self):
        super().__init__("smtp.orange.fr", 465, 25 * 1024 * 1024)



import smtplib

class EmailSender:
    def __init__(self, service, login: str, password: str):
        self.service = service
        self.login = login
        self.password = password

    def send(self, to_email: str, msg) -> str:
        try:
            with smtplib.SMTP(self.service.server, self.service.port) as server:
                server.starttls()
                server.login(self.login, self.password)
                server.sendmail(self.login, to_email, msg.as_string())
            return "Email sent successfully"
        except Exception as e:
            return f"Error sending email: {e}"



import os
import mimetypes
from email.mime.base import MIMEBase
from email import encoders

class AttachmentHandler:
    def __init__(self, validator):
        self.validator = validator

    def add_attachments(self, msg, file_paths):
        self.validator.validate(file_paths)
        for path in file_paths:
            mime_type, _ = mimetypes.guess_type(path)
            if not mime_type:
                raise ValueError(f"Unsupported MIME type for file {path}")

            main, sub = mime_type.split("/")
            with open(path, "rb") as f:
                part = MIMEBase(main, sub)
                part.set_payload(f.read())
                encoders.encode_base64(part)

            filename = os.path.basename(path)
            part.add_header("Content-Disposition", f"attachment; filename={filename}")
            msg.attach(part)



import sys
import os
from dotenv import load_dotenv

load_dotenv()  # load content in file .env

email_sender = os.getenv('EMAIL_SENDER')  # get sender email

email_dest = os.getenv('EMAIL_DEST') # get email dest

email_password = os.getenv('EMAIL_PASSWORD')  # get application password

email_cc = os.getenv('EMAIL_CC') # copy recipient

email_bcc = os.getenv('EMAIL_BCC') # hidden copy recipient


sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

BASE_DIR = os.path.dirname(os.path.abspath(__file__))

list_files = [
    os.path.join(BASE_DIR, "random.hpp"),
    os.path.join(BASE_DIR, "test.pdf")
]


from lycosa.sender import EmailClient, Gmail

# Choose the email service : Gmail, Orange
service = Gmail()

# Login credentials
login = email_sender
password = email_password  # application password

# Create a customer
client = EmailClient(service, login, password)


html_message = """
<html>
    <body>
        <h1 style="color:blue;">This is an HTML test!</h1>
        <p>Sending an email in <b>HTML</b> with an attachment.</p>
    </body>
</html>
"""

txt_message = "This is a test of sending email through my library."

# Send a simple email
result = client.send_email(
    to=email_dest,
    subject="Hello",
    body=html_message,
    files=[list_files[0], list_files[1]],
    cc=["collaborateur@example.com"],
    bcc=["boss@example.com"], 
    body_type="html"
)

print(result) 


from .email_sender import EmailSender
from .email_builder import EmailBuilder
from .file_validator import FileValidator
from .attachment_handler import AttachmentHandler

class EmailClient:
    def __init__(self, service, login, password):
        self.service = service
        self.sender = EmailSender(service, login, password)
        self.builder = EmailBuilder(login)
        self.validator = FileValidator(service)
        self.attachment_handler = AttachmentHandler(self.validator)

    def send_email(self, to, subject, body, files=None, cc=None, bcc=None, body_type="plain"):
        msg = self.builder.build(to, subject, body, body_type, cc, bcc)
        if files:
            self.attachment_handler.add_attachments(msg, files)
        return self.sender.send(to, msg)



import os

class FileValidator:
    def __init__(self, service):
        self.service = service

    def validate(self, files):
        total_size = 0
        for file in files:
            if not os.path.isfile(file):
                raise FileNotFoundError(f"File {file} does not exist.")
            total_size += os.path.getsize(file)

        if total_size > self.service.max_size_bytes:
            raise ValueError("Total attachment size exceeds the limit.")



from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText

class EmailBuilder:
    def __init__(self, sender_email: str):
        self.sender_email = sender_email

    def build(self, to, subject, body, body_type="plain", cc=None, bcc=None):
        msg = MIMEMultipart()
        msg["From"] = self.sender_email
        msg["To"] = to
        msg["Subject"] = subject

        if cc:
            msg["Cc"] = ', '.join(cc)
        if bcc:
            msg["Bcc"] = ', '.join(bcc)

        msg.attach(MIMEText(body, body_type))
        return msg
